<TS version="2.1" language="is">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Smelltu á hægri músatakka til að velja veski eða merkingu</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Búa til nýtt veski</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Nýtt</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Afrita</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">&amp;Loka</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Eyða völdu veski úr listanum</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Veldu veski eða merkingu fyrir leit</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Flyttu gögnin í núverandi flipa út í skrá                                                                    </translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Flytja út</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Eyða</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Veldu veski sem greiða skal til</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Veldu veski til að taka við rafmynt</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">&amp;Veldu</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Þetta eru Bitcoin veskin sem senda greiðslur. Skoðið ævinlega vel upphæðina og veskin sem þiggja greiðslur áður en rafmynt er send.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">Þetta eru Bitcoin heimilisföngin þín til að taka á móti greiðslum. Notaðu hnappinn „Búa til nýtt móttökuheimilisfang“ á móttökuflipanum til að búa til ný heimilisföng. Undirskrift er aðeins möguleg með heimilisföngum af gerðinni „arfleifð“.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Afrita færslugildi</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Afrita og &amp;Merkja</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Breyta</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Flytja út færslulista</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">Ekki tókst að vista færslugildalistann á %1. Reyndu aftur.</translation>
    </message>
    <message>
        <source>Sending addresses - %1</source>
        <translation type="unfinished">heimilisföng - %1 </translation>
    </message>
    <message>
        <source>Receiving addresses - %1</source>
        <translation type="unfinished">heimilisföng - %1</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Útflutningur tókst ekki</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Merki</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Færslugildi</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(engin merking)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Lykilsetning</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Skráðu lykilsetningu</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Ný lykilsetning</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Endurtaktu nýja lykilsetningu</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">lykilorð</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Dulkóða veski</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Þessi aðgerð þarf að fá lykilsetninguna þína til að opna veskið.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Opna veskið</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Breyta lykilsetningu</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Staðfesta dulkóðun veskis</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Viðvörun: Ef þú dulkóðar veskið og týnir lykilsetningunn þá munt þú &lt;b&gt;TAPA ALLRI ÞINNI BITCOIN MYNT&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Ertu viss um að þú viljir dulkóða veskið þitt?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Veski dulkóðað</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">Sláðu inn nýja lykilorðið fyrir veskið. Vinsamlega notaðu aðgangsorð sem inniheldur tíu eða fleiri handahófskennda stafi, eða átta eða fleiri orð. </translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">Sláðu inn gamla lykilorðið og nýja lykilorðið fyrir veskið.</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">Mundu að dulkóðun vesksins þíns getur ekki verndað bitcoins þína að fullu gegn því að vera stolið af spilliforritum sem sýkja tölvuna þína.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Veski sem á að dulkóða</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">Veskið þitt er um það bil að vera dulkóðað.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">Veskið þitt er um það bil að vera dulkóðað.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">MIKILVÆGT: Nýja dulkóðaða veskisskráin þarf að koma í staðinn fyrir öll fyrri afrit sem þú hefur gert af upprunalegu veskisskránni. Af öryggisástæðum munu öll fyrri afrit af ódulkóðaða veskinu verða óvirk um leið og þú byrjar að nota nýja, dulkóðaða veskið.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Dulkóðun veskis mistókst</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Dulkóðun veskis mistóks vegna innri villu. Veskið þitt var ekki dulkóðað.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Lykilsetningarnar eru ekki þær sömu.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Ekki tókst að opna veskið</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Lykilsetningin sem notuð var til að dulráða veskið var ekki rétt.</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character. If this is successful, please set a new passphrase to avoid this issue in the future.</source>
        <translation type="unfinished">Aðgangsorðið sem slegið var inn fyrir afkóðun vesksins er rangt. Það inniheldur núllstaf (þ.e. - núll bæti). Ef lykilorðið var stillt með útgáfu af þessum hugbúnaði fyrir 25.0, vinsamlegast reyndu aftur með aðeins stöfunum upp að — en ekki með — fyrsta núllstafnum. Ef þetta tekst, vinsamlegast stilltu nýtt lykilorð til að forðast þetta vandamál í framtíðinni.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Það tókst að breyta lykilsetningu veskis.</translation>
    </message>
    <message>
        <source>Passphrase change failed</source>
        <translation type="unfinished">Mistókst að breyta lykilorði</translation>
    </message>
    <message>
        <source>The old passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character.</source>
        <translation type="unfinished">Gamla lykilorðið sem slegið var inn fyrir afkóðun vesksins er rangt. Það inniheldur núllstaf (þ.e. - núll bæti). Ef lykilorðið var stillt með útgáfu af þessum hugbúnaði fyrir 25.0, vinsamlegast reyndu aftur með aðeins stöfunum upp að — en ekki með — fyrsta núllstafnum.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Viðvörun: Kveikt er á HÁSTÖFUM!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation type="unfinished">IP/Netgríma</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Bannað til</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">Stillingaskrá %1 gæti verið skemmd eða ógild.</translation>
    </message>
    <message>
        <source>Runaway exception</source>
        <translation type="unfinished">Undantekning á flótta</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">Banvæn villa kom upp. %1 getur ekki lengur haldið áfram á öruggan hátt og mun hætta.</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Innri villa</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">Innri villa kom upp. %1 mun reyna að halda áfram á öruggan hátt. Þetta er óvænt villa sem hægt er að tilkynna eins og lýst er hér að neðan.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">Viltu endurstilla stillingar á sjálfgefin gildi, eða hætta án þess að gera breytingar?</translation>
    </message>
    <message>
        <source>A fatal error occurred. Check that settings file is writable, or try running with -nosettings.</source>
        <extracomment>Explanatory text shown on startup when the settings file could not be written. Prompts user to check that we have the ability to write to the file. Explains that the user has the option of running without a settings file.</extracomment>
        <translation type="unfinished">Banvæn villa kom upp. Athugaðu hvort stillingarskráin sé skrifanleg eða reyndu að keyra með -nosettings.</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Villa: %1</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1 fór ekki enn á öruggan hátt…</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Upphæð</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;Yfirlit</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">Sýna almennt yfirlit af veski</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Færslur</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Skoða færslusögu</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">&amp;Hætta</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Hætta í forriti</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;Um %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">Sýna upplýsingar um %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Um &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Sýna upplýsingar um Qt</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">Breyta samstillingum fyrir %1</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Búðu til nýtt veski</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">&amp;Lágmarka</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Veski:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">Slökkt á netumferð.</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation type="unfinished">Umboð er virkt: %1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Senda mynt í Bitcoin færslugildi</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">Öryggisafrita veski á annan stað</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Breyta lykilsetningunni sem gildir um dulkóðun veskis</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Senda</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Taka við</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;Valkostir…</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">&amp;Dulkóða veski...</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">Dulkóða einkalyklana sem tilheyra veskinu þínu</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet…</source>
        <translation type="unfinished">&amp;Öryggisveski...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">&amp;Breyta lykilorði...</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">Skrifaðu undir &amp;skilaboð...</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Kvitta undir skilaboð með Bitcoin færslugildunum þínum til að sanna að þú eigir þau</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp;Staðfestu skilaboð...</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">Yfirfara skilaboð til að tryggja að kvittað hafi verið fyrir þau með tilteknum Bitcoin færslugildum</translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file…</source>
        <translation type="unfinished">&amp;Hlaða PSBT úr skrá...</translation>
    </message>
    <message>
        <source>Open &amp;URI…</source>
        <translation type="unfinished">Opnaðu &amp;URI...</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">Loka veski...</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">Búa til veski...</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">Lokaðu öllum veski...</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Skrá</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Stillingar</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Hjálp</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">Tólaborð flipa</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)…</source>
        <translation type="unfinished">Samstillir hausa (%1%)…</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">Samstillir við net…</translation>
    </message>
    <message>
        <source>Indexing blocks on disk…</source>
        <translation type="unfinished">Vísar blokkir á disk...</translation>
    </message>
    <message>
        <source>Processing blocks on disk…</source>
        <translation type="unfinished">Vinnur úr blokkum á diski...</translation>
    </message>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">Tengist jafnöldrum...</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">Óska eftir greiðslum (býr til QR kóða og bitcoin: URI)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">Sýna lista yfir færslugildi sem notuð hafa verið til sendingar og merkingar þeirra</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">Sýna færslugildi sem notuð hafa verið til að taka við mynt og merkingar þeirra</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">&amp;Valkostir skipanalínu</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 á eftir</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">Síðasta viðtekna blokk var búin til fyrir %1 síðan.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">Færslur á eftir þessari munu ekki sjást.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Villa</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Viðvörun</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Upplýsingar</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Uppfært</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation type="unfinished">Sýna %1 hjálparskilaboðin til að fá lista yfir valkosti Bitcoin aðgerðir í skipanalínu</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">%1 biðlarar</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Villa: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">Dagsetning: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">Upphæð: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation type="unfinished">Tegund: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation type="unfinished">Merki: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">Færslugildi: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation type="unfinished">Send færsla</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation type="unfinished">Móttökufærsla</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation type="unfinished">HD lyklagerð er &lt;b&gt;virkjuð&lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">HD lyklagerð er &lt;b&gt;óvirk&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation type="unfinished">Veskið er &lt;b&gt;dulkóðað&lt;/b&gt; og núna &lt;b&gt;ólæst&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation type="unfinished">Veskið er &lt;b&gt;dulkóðað&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation type="unfinished">Myntval</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Magn:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Bæti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Upphæð:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Gjald:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Eftirgjald:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Skiptimynt:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation type="unfinished">(af)velja allt</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation type="unfinished">Hrísluhamur</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation type="unfinished">Listahamur</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Upphæð</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation type="unfinished">Móttekið með merkingu</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation type="unfinished">Móttekið með færslugildi</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID and output index</source>
        <translation type="unfinished">Afritaðu færslu &amp; auðkenni og úttaksvísitölu</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(engin merking)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Too many external signers found</source>
        <translation type="unfinished">Of margir ytri undirritarar fundust</translation>
    </message>
</context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Veski</translation>
    </message>
    <message>
        <source>Use an external signing device such as a hardware wallet. Configure the external signer script in wallet preferences first.</source>
        <translation type="unfinished">Notaðu utanaðkomandi undirritunartæki eins og vélbúnaðarveski. Stilltu ytri undirritarahandritið í veskisstillingum fyrst.</translation>
    </message>
    <message>
        <source>External signer</source>
        <translation type="unfinished">Ytri undirritari</translation>
    </message>
    <message>
        <source>Compiled without external signing support (required for external signing)</source>
        <extracomment>"External signing" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">Samið án utanaðkomandi undirskriftarstuðnings (krafist fyrir utanaðkomandi undirskrift)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">Breyta færslugildi</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;Merki</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation type="unfinished">Merking tengd þessu færslugildi</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation type="unfinished">Færslugildið sem tengt er þessari færslu. Þessu má einungis breyta þegar sent er.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">Nýtt móttökufærslugildi</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation type="unfinished">Nýtt sendingarfærslugildi</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation type="unfinished">Breyta móttökufærslugildi</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">Breyta sendingarfærslugildi</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation type="unfinished">Færslugildið sem slegið var inn "%1" er ekki leyfilegt Bitcoin færslugildi.</translation>
    </message>
    <message>
        <source>Address "%1" already exists as a receiving address with label "%2" and so cannot be added as a sending address.</source>
        <translation type="unfinished">Heimilisfangið "%1" er nú þegar til sem móttökunetfang með merkimiðanum "%2" og því er ekki hægt að bæta við sem sendanda.</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation type="unfinished">Skráin er þegar til. Bættu við %1 ef þú ætlar að búa til nýja möppu hér.</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation type="unfinished">Slóð er þegar til og er ekki skrá.</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>This initial synchronisation is very demanding, and may expose hardware problems with your computer that had previously gone unnoticed. Each time you run %1, it will continue downloading where it left off.</source>
        <translation type="unfinished">Þessi fyrstu samstilling er mjög krefjandi og getur leitt til vélbúnaðarvandamála með tölvunni þinni sem áður hafði farið framhjá. Í hvert skipti sem þú keyrir %1 mun það halda áfram að hlaða niður þar sem frá var horfið.</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Approximately %1 GB of data will be stored in this directory.</source>
        <translation type="unfinished">Um það bil %1 GB af gögnum verða geymd í þessari möppu.</translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Villa</translation>
    </message>
</context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Number of blocks left</source>
        <translation type="unfinished">Fjöldi blokka sem eftir eru</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">Tími síðustu blokkar</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation type="unfinished">IP tala staðgengils (t.d. IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>Shows if the supplied default SOCKS5 proxy is used to reach peers via this network type.</source>
        <translation type="unfinished">Sýnir hvort meðfylgjandi sjálfgefna SOCKS5 proxy er notaður til að ná til jafningja í gegnum þessa nettegund.</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Exit in the menu.</source>
        <translation type="unfinished">Lágmarkaðu í stað þess að hætta í forritinu þegar glugginn er lokaður. Þegar þessi valkostur er virkur verður forritinu aðeins lokað eftir að Hætta er valið í valmyndinni.</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation type="unfinished">Sérfræðingur</translation>
    </message>
    <message>
        <source>External Signer (e.g. hardware wallet)</source>
        <translation type="unfinished">Ytri undirritari (t.d. vélbúnaðarveski)</translation>
    </message>
    <message>
        <source>&amp;External signer script path</source>
        <translation type="unfinished">&amp;Ytri undirskriftarslóð</translation>
    </message>
    <message>
        <source>Connect to the Bitcoin network through a SOCKS5 proxy.</source>
        <translation type="unfinished">Tengstu Bitcoin netinu í gegnum SOCKS5 umboð.</translation>
    </message>
    <message>
        <source>&amp;Connect through SOCKS5 proxy (default proxy):</source>
        <translation type="unfinished">&amp;Tengdu í gegnum SOCKS5 proxy (sjálfgefinn proxy):</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation type="unfinished">Umboð &amp; IP:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation type="unfinished">Gátt umboðsins (t.d. 9050)</translation>
    </message>
    <message>
        <source>Third-party URLs (e.g. a block explorer) that appear in the transactions tab as context menu items. %s in the URL is replaced by transaction hash. Multiple URLs are separated by vertical bar |.</source>
        <translation type="unfinished">Vefslóðir þriðja aðila (t.d. blokkkönnuður) sem birtast á færsluflipanum sem samhengisvalmyndaratriði. %s í vefslóðinni er skipt út fyrir færsluhash. Margar vefslóðir eru aðskildar með lóðréttri strik |.</translation>
    </message>
    <message>
        <source>Connect to the Bitcoin network through a separate SOCKS5 proxy for Tor onion services.</source>
        <translation type="unfinished">Tengstu Bitcoin netinu í gegnum sérstakt SOCKS5 umboð fyrir Tor laukþjónustu.</translation>
    </message>
    <message>
        <source>Use separate SOCKS&amp;5 proxy to reach peers via Tor onion services:</source>
        <translation type="unfinished">Notaðu sérstakan SOCKS&amp;5 proxy til að ná til jafningja í gegnum Tor onion þjónustu:</translation>
    </message>
    <message>
        <source>Compiled without external signing support (required for external signing)</source>
        <extracomment>"External signing" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">Samið án utanaðkomandi undirskriftarstuðnings (krafist fyrir utanaðkomandi undirskrift)</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Villa</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation type="unfinished">Uppgefið færslugildi staðgengils er ógilt.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Mined balance that has not yet matured</source>
        <translation type="unfinished">Námuunnin innistæða sem hefur enn ekki komið fram</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Sign Tx</source>
        <translation type="unfinished">Skilti Tx</translation>
    </message>
    <message>
        <source>Broadcast Tx</source>
        <translation type="unfinished">Útsending Tx</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Færslugildi</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation type="unfinished">URI varð of langt, reyndu að minnka texta í merki / skilaboðum.</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Block chain</source>
        <translation type="unfinished">Blokkarkeðja</translation>
    </message>
    <message>
        <source>Starting Block</source>
        <translation type="unfinished">Upphafsblokk</translation>
    </message>
    <message>
        <source>Synced Blocks</source>
        <translation type="unfinished">Samhæfðar blokkir</translation>
    </message>
    <message>
        <source>The total number of addresses received from this peer that were processed (excludes addresses that were dropped due to rate-limiting).</source>
        <extracomment>Tooltip text for the Addresses Processed field in the peer details area, which displays the total number of addresses received from this peer that were processed (excludes addresses that were dropped due to rate-limiting).</extracomment>
        <translation type="unfinished">Heildarfjöldi heimilisfönga sem berast frá þessum jafningja sem voru unnin (án utan heimilisföng sem voru sleppt vegna gjaldtakmarkana).</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">Tími síðustu blokkar</translation>
    </message>
    <message>
        <source>v1: unencrypted, plaintext transport protocol</source>
        <extracomment>Explanatory text for v1 transport type.</extracomment>
        <translation type="unfinished">v1: ódulkóðuð, látlaus flutningsaðferð</translation>
    </message>
    <message>
        <source>Executing command without any wallet</source>
        <translation type="unfinished">Framkvæmir skipun án veskis</translation>
    </message>
    <message>
        <source>Executing command using "%1" wallet</source>
        <translation type="unfinished">Framkvæmir skipun með "%1" veski</translation>
    </message>
    <message>
        <source>Executing…</source>
        <extracomment>A console message indicating an entered command is currently being executed.</extracomment>
        <translation type="unfinished">Framkvæmir…</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Merki:</translation>
    </message>
    <message>
        <source>An optional label to associate with the new receiving address.</source>
        <translation type="unfinished">Valfrjálst merki sem tengist nýju móttökufærslutölunni.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Upphæð:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Veski:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Merki</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(engin merking)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Magn:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Bæti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Upphæð:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Gjald:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Eftirgjald:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Skiptimynt:</translation>
    </message>
    <message>
        <source>Set external signer script path in Options -&gt; Wallet</source>
        <extracomment>"External signer" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">Stilltu forskriftarslóð ytri undirritara í Valkostir -&gt; Veski</translation>
    </message>
    <message>
        <source>External signer not found</source>
        <extracomment>"External signer" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">Ytri undirritari fannst ekki</translation>
    </message>
    <message>
        <source>External signer failure</source>
        <extracomment>"External signer" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">Bilun í ytri undirritara</translation>
    </message>
    <message>
        <source>External balance:</source>
        <translation type="unfinished">Ytra jafnvægi:</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation type="unfinished">Upphæðin fer yfir stöðu þína.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation type="unfinished">Heildarkostnaður fer yfir stöðuna þína þegar %1 færslugjaldið er innifalið.</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(engin merking)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Merki:</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Enter the receiver's address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack. Note that this only proves the signing party receives with the address, it cannot prove sendership of any transaction!</source>
        <translation type="unfinished">Sláðu inn heimilisfang viðtakanda, skilaboð (passaðu að þú afritar línuskil, bil, flipa osfrv. nákvæmlega) og undirskrift hér að neðan til að staðfesta skilaboðin. Gættu þess að lesa ekki meira inn í undirskriftina en það sem er í undirrituðu skilaboðunum sjálfum, til að forðast að láta blekkjast af mann-í-miðju árás. Athugaðu að þetta sannar aðeins að undirritaður aðili fær með heimilisfanginu, það getur ekki sannað sendanda á neinni færslu!</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Output index</source>
        <translation type="unfinished">Framleiðsluvísitala</translation>
    </message>
    <message>
        <source>Generated coins must mature %1 blocks before they can be spent. When you generated this block, it was broadcast to the network to be added to the block chain. If it fails to get into the chain, its state will change to "not accepted" and it won't be spendable. This may occasionally happen if another node generates a block within a few seconds of yours.</source>
        <translation type="unfinished">Fullgerð mynt verður að nýta %1 blokkir. Þegar þú bjóst til þessa blokk, þá var jafnóðum tilkynnt á netinu að hún eigi að bætast við blokkakeðjuna. Ef hún kemst ekki í keðjuna þá mun staða hennar breytast í "ósamþykkt" og ekki verður hægt að nota hana. Þetta gerist annað slagið ef annar hnútpunktur klárar blokk nokkrum sekúndum á undan þinni.</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Upphæð</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Merki</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation type="unfinished">Námuunnið</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(engin merking)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Mined</source>
        <translation type="unfinished">Námuunnið</translation>
    </message>
    <message>
        <source>Export Transaction History</source>
        <translation type="unfinished">Flytja út viðskiptasögu</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">aðskilin skrá</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Merki</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Færslugildi</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Útflutningur tókst ekki</translation>
    </message>
    <message>
        <source>Exporting Successful</source>
        <translation type="unfinished">Útflutningur tókst</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Búðu til nýtt veski</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Villa</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Warning: This may pay the additional fee by reducing change outputs or adding inputs, when necessary. It may add a new change output if one does not already exist. These changes may potentially leak privacy.</source>
        <translation type="unfinished">Viðvörun: Þetta gæti borgað aukagjaldið með því að draga úr breytingaútgangi eða bæta við aðföngum, þegar þörf krefur. Það gæti bætt við nýju breytingaúttaki ef það er ekki þegar til. Þessar breytingar gætu hugsanlega lekið friðhelgi einkalífsins.</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Flytja út</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Flyttu gögnin í núverandi flipa út í skrá                                                                    </translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>%s failed to validate the -assumeutxo snapshot state. This indicates a hardware problem, or a bug in the software, or a bad software modification that allowed an invalid snapshot to be loaded. As a result of this, the node will shut down and stop using any state that was built on the snapshot, resetting the chain height from %d to %d. On the next restart, the node will resume syncing from %d without using any snapshot data. Please report this incident to %s, including how you obtained the snapshot. The invalid snapshot chainstate will be left on disk in case it is helpful in diagnosing the issue that caused this error.</source>
        <translation type="unfinished">%s tókst ekki að staðfesta -assumeutxo skyndimyndastöðu. Þetta gefur til kynna vélbúnaðarvandamál, eða villu í hugbúnaðinum, eða slæma hugbúnaðarbreytingu sem gerði kleift að hlaða ógildri skyndimynd. Sem afleiðing af þessu mun hnúturinn lokast og hætta að nota hvaða ástand sem var byggt á skyndimyndinni og endurstilla keðjuhæðina úr %d í %d. Við næstu endurræsingu mun hnúturinn halda áfram samstillingu frá %d án þess að nota nokkur skyndimyndagögn. Vinsamlegast tilkynntu þetta atvik til %s, þar á meðal hvernig þú náðir myndinni. Ógilt skyndimynd chainstate verður skilið eftir á disknum ef það er gagnlegt við að greina vandamálið sem olli þessari villu.</translation>
    </message>
    <message>
        <source>Disk space for %s may not accommodate the block files. Approximately %u GB of data will be stored in this directory.</source>
        <translation type="unfinished">Diskapláss fyrir %s rúmar kannski ekki blokkarskrárnar. Um það bil %u GB af gögnum verða geymd í þessari möppu.</translation>
    </message>
    <message>
        <source>Error loading wallet. Wallet requires blocks to be downloaded, and software does not currently support loading wallets while blocks are being downloaded out of order when using assumeutxo snapshots. Wallet should be able to load successfully after node sync reaches height %s</source>
        <translation type="unfinished">Villa við að hlaða veski. Veski krefst þess að kubbum sé hlaðið niður og hugbúnaður styður ekki hleðslu veski eins og er á meðan verið er að hlaða niður kubbum úr röð þegar assumeutxo skyndimyndir eru notaðar. Veski ætti að geta hlaðið upp eftir að hnútsamstilling nær hæð %s</translation>
    </message>
    <message>
        <source>Error: Dumpfile format record is incorrect. Got "%s", expected "format".</source>
        <translation type="unfinished">Villa: Skráning á sorpskráarsniði er röng. Fékk "%s", búist við "sniði".</translation>
    </message>
    <message>
        <source>Error: Dumpfile identifier record is incorrect. Got "%s", expected "%s".</source>
        <translation type="unfinished">Villa: Auðkennisskrá dumpfile er röng. Fékk "%s", bjóst við "%s".</translation>
    </message>
    <message>
        <source>File %s already exists. If you are sure this is what you want, move it out of the way first.</source>
        <translation type="unfinished">Skráin %s er þegar til. Ef þú ert viss um að þetta sé það sem þú vilt skaltu færa það úr vegi fyrst.</translation>
    </message>
    <message>
        <source>Invalid or corrupt peers.dat (%s). If you believe this is a bug, please report it to %s. As a workaround, you can move the file (%s) out of the way (rename, move, or delete) to have a new one created on the next start.</source>
        <translation type="unfinished">Ógild eða skemmd peers.dat (%s). Ef þú telur að þetta sé galli, vinsamlegast tilkynntu það til %s. Sem lausn geturðu fært skrána (%s) úr vegi (endurnefna, færa eða eyða) til að búa til nýja við næstu byrjun.</translation>
    </message>
    <message>
        <source>Prune mode is incompatible with -reindex-chainstate. Use full -reindex instead.</source>
        <translation type="unfinished">Prune háttur er ósamrýmanlegur -reindex-chainstate. Notaðu fulla -reindex í staðinn.</translation>
    </message>
    <message>
        <source>Rename of '%s' -&gt; '%s' failed. You should resolve this by manually moving or deleting the invalid snapshot directory %s, otherwise you will encounter the same error again on the next startup.</source>
        <translation type="unfinished">Mistókst að endurnefna '%s' -&gt; '%s'. Þú ættir að leysa þetta með því að færa handvirkt eða eyða ógildu skyndimyndamöppunni %s, annars muntu lenda í sömu villu aftur við næstu ræsingu.</translation>
    </message>
    <message>
        <source>This is the maximum transaction fee you pay (in addition to the normal fee) to prioritize partial spend avoidance over regular coin selection.</source>
        <translation type="unfinished">Þetta er hámarks viðskiptagjaldið sem þú greiðir (til viðbótar við venjulega gjaldið) til að forgangsraða að hluta til að forðast eyðslu fram yfir venjulegt myntval.</translation>
    </message>
    <message>
        <source>Total length of network version string (%i) exceeds maximum length (%i). Reduce the number or size of uacomments.</source>
        <translation type="unfinished">Heildarlengd netútgáfustrengs (%i) fer yfir hámarkslengd (%i). Fækkaðu fjölda eða stærð ua athugasemda.</translation>
    </message>
    <message>
        <source>Unable to replay blocks. You will need to rebuild the database using -reindex-chainstate.</source>
        <translation type="unfinished">Ekki hægt að spila kubba aftur. Þú þarft að endurbyggja gagnagrunninn með því að nota -reindex-chainstate.</translation>
    </message>
    <message>
        <source>Unsupported category-specific logging level %1$s=%2$s. Expected %1$s=&lt;category&gt;:&lt;loglevel&gt;. Valid categories: %3$s. Valid loglevels: %4$s.</source>
        <translation type="unfinished">Óstudd flokkasértæk skráningarstig %1$s=%2$s. Búist var við %1$s=:. Gildir flokkar: %3$s. Gild logstig: %4$s.</translation>
    </message>
    <message>
        <source>Unsupported chainstate database format found. Please restart with -reindex-chainstate. This will rebuild the chainstate database.</source>
        <translation type="unfinished">Óstudd snið chainstate gagnagrunns fannst. Vinsamlegast endurræstu með -reindex-chainstate. Þetta mun endurbyggja chainstate gagnagrunninn.</translation>
    </message>
    <message>
        <source>Witness data for blocks after height %d requires validation. Please restart with -reindex.</source>
        <translation type="unfinished">Vitnisgögn fyrir blokkir eftir hæð %d krefjast staðfestingar. Vinsamlegast endurræstu með -reindex.</translation>
    </message>
    <message>
        <source>You need to rebuild the database using -reindex to go back to unpruned mode.  This will redownload the entire blockchain</source>
        <translation type="unfinished">Þú þarft að endurbyggja gagnagrunninn með því að nota -reindex til að fara aftur í óklippta stillingu. Þetta mun hlaða niður öllu blockchain aftur</translation>
    </message>
    <message>
        <source>-maxmempool must be at least %d MB</source>
        <translation type="unfinished">-maxmempool verður að vera að minnsta kosti %d MB</translation>
    </message>
    <message>
        <source>Cannot set -peerblockfilters without -blockfilterindex.</source>
        <translation type="unfinished">Get ekki stillt -peerblockfilters án -blockfilterindex.</translation>
    </message>
    <message>
        <source>Error loading %s: External signer wallet being loaded without external signer support compiled</source>
        <translation type="unfinished">Villa við að hlaða %s: Ytra undirritaraveski verið hlaðið án þess að utanaðkomandi undirritarastuðningur hafi verið settur saman</translation>
    </message>
    </context>
</TS>